UserContentController class

Constructors

UserContentController()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addUserOnlyScript(UserScript userScript) → void
addUserOnlyScripts(List<UserScript> userScripts) → void
dispose() → void
getUserOnlyScriptsAt(UserScriptInjectionTime injectionTime) → List<UserScript>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllUserOnlyScripts() → dynamic
removeUserOnlyScript(UserScript userScript) → bool
removeUserOnlyScriptAt(int index, UserScriptInjectionTime injectionTime) → UserScript
removeUserOnlyScriptsByGroupName(String groupName) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited